@@ -7,7 +7,7 @@ use warnings;
 # One for use with whatever you originally need for.
 # Another for use with this module (Finance::Asset)
 
-use YAML::XS qw(LoadFile DumpFile);
+use YAML::CacheLoader qw(LoadFile DumpFile);
 use Data::Dumper;
 
 my $input_yml       = shift or die "YAML file needed as input param";
